@@ -29,7 +29,6 @@ def send_email_message(server: smtplib.SMTP, msg: EmailMessage) -> bool:
 
 def send_email_messages(msgs: List[EmailMessage]) -> int:
     """Send an email"""
-    # TODO: Consider making smtp server configurable
     messages_sent = 0
     try:
         logger.debug("Connecting to SMTP...")
@@ -40,38 +39,38 @@ def send_email_messages(msgs: List[EmailMessage]) -> int:
             for msg in msgs:
                 if send_email_message(server, msg):
                     messages_sent += 1
-                    logger.info("Email sent successfully!")
+                    logger.notice("Email sent successfully!\n")
     except smtplib.SMTPException as e:
         logger.error(f"Caught an exception while trying to send an email.\nError: {e}")
     return messages_sent
 
 
-def set_content(msg: EmailMessage, title: str, url: Optional[str], content: Optional[str]) -> None:
+def set_content(msg: EmailMessage, title: str, url: Optional[str], attachment_path: Optional[str]) -> None:
     """Either set the text content of the email message, or attach an attachment, based on the current parser"""
-    if content:
+    if attachment_path:
+        # We are marking the attachment as HTML, although it's an epub, because kindle doesn't official accept
+        # EPUB files in emails, but unofficial it will convert the file with kindlegen and it'll work fine
+        # Reference: https://www.amazon.com/gp/sendtokindle/email
         filename = f"{title}.html"
-        logger.debug(f"Setting attachment for {filename}")
-        msg.add_attachment(
-            content.encode("utf-8"),
-            maintype="text",
-            subtype=f'html; charset=utf-8; name="{filename}"',
-            filename=filename,
-        )
+        logger.debug(f"Setting attachment for {title}")
+        with open(attachment_path, "rb") as f:
+            msg.add_attachment(
+                f.read(), maintype="text", subtype=f'html; charset=utf-8; name="{filename}"', filename=filename,
+            )
     elif url:
         logger.debug(f"Setting email content to {url}")
         msg.set_content(url)
 
 
-def create_email_message(title: str, url: Optional[str], content: Optional[str]) -> EmailMessage:
+def create_email_message(title: str, url: Optional[str], attachment_path: Optional[str]) -> EmailMessage:
     title = strip_common_unicode_chars(title)
     msg = build_basic_message(title)
-    set_content(msg, title, url, content)
+    set_content(msg, title, url, attachment_path)
     return msg
 
 
-def send_html(title: str, content: str) -> int:
-    """Send an HTML file to Kindle"""
-    msg = create_email_message(title, None, content)
+def send_epub(title: str, epub_path: str) -> int:
+    msg = create_email_message(title, None, epub_path)
     return send_email_messages([msg])
 
 
